##
##  tsuru.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2019 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_tsuru_base 1.7.4
%define       V_tsuru_snap 20190831

#   package information
Name:         tsuru
Summary:      Platform as a Service (PaaS) System
URL:          http://tsuru.io/
Vendor:       tsuru Project
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Networking
License:      MIT
Version:      %{V_tsuru_base}.%{V_tsuru_snap}
Release:      20190831

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/tsuru/tsuru-%{V_tsuru_snap}.tar.xz
Source1:      rc.tsuru
Patch0:       tsuru.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101

%description
    tsuru is an extensible and open source Platform as a Service (PaaS)
    that makes application deployments faster and easier. With tsuru,
    you don’t need to think about servers at all. As an application
    developer, you can: write apps in the programming language of your
    choice, back apps with add-on resources such as SQL and NoSQL
    databases, including memcached, redis, and many others. manage apps
    using the tsuru command-line tool and deploy apps using the Git
    revision control system.

%track
    prog tsuru:release = {
        version   = %{V_tsuru_base}
        url       = https://github.com/tsuru/tsuru/releases
        regex     = (\d+\.\d+\.\d+)\.tar\.gz
    }
    prog tsuru:snapshot = {
        version   = %{V_tsuru_snap}
        url       = http://download.openpkg.org/components/versioned/tsuru/
        regex     = tsuru-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n tsuru
    %patch -p0

%build
    #   build program
    export GOPATH=`pwd`
    (   cd src/github.com/tsuru/tsuru
        %{l_make} %{l_mflags} binaries
    ) || exit $?

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/sbin \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d \
        $RPM_BUILD_ROOT%{l_prefix}/etc/tsuru \
        $RPM_BUILD_ROOT%{l_prefix}/var/tsuru/log \
        $RPM_BUILD_ROOT%{l_prefix}/var/tsuru/run

    #   install programs
    %{l_shtool} install -c -s -m 755 \
        src/github.com/tsuru/tsuru/build/tsurud \
        $RPM_BUILD_ROOT%{l_prefix}/sbin/

    #   install run-command script
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.tsuru} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/tsuru' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/tsuru/*'

%files -f files

%clean

%post
    #   after upgrade, restart service
    [ $1 -eq 2 ] || exit 0
    eval `%{l_rc} tsuru status 2>/dev/null`
    [ ".$tsuru_active" = .yes ] && %{l_rc} tsuru restart
    exit 0

%preun
    #   before erase, stop service and remove log files
    [ $1 -eq 0 ] || exit 0
    %{l_rc} tsuru stop 2>/dev/null
    rm -rf $RPM_INSTALL_PREFIX/var/tsuru/log/* >/dev/null 2>&1 || true
    rm -rf $RPM_INSTALL_PREFIX/var/tsuru/run/* >/dev/null 2>&1 || true
    exit 0

